"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceBootstrapBash = exports.replaceBinDeno = exports.ensureBash = exports.ensureDeno = void 0;
const path_1 = __importDefault(require("path"));
const command_exists_1 = __importDefault(require("command-exists"));
const which_1 = __importDefault(require("which"));
const fs_extra_1 = require("fs-extra");
async function ensureDeno() {
    try {
        await command_exists_1.default('deno');
    }
    catch (error) {
        console.error('deno is not installed or not in your PATH. Please install deno from https://deno.land/.');
        throw error;
    }
}
exports.ensureDeno = ensureDeno;
async function ensureBash() {
    try {
        await command_exists_1.default('bash');
    }
    catch (error) {
        console.error('bash is not installed or not in your PATH. Please install bash or add it to your PATH.');
        throw error;
    }
}
exports.ensureBash = ensureBash;
async function replaceBinDeno(workPath) {
    const denoPath = await which_1.default('deno');
    const binDenoPath = path_1.default.join(workPath, 'layer', 'bin', 'deno');
    await fs_extra_1.remove(binDenoPath);
    await fs_extra_1.symlink(denoPath, binDenoPath);
}
exports.replaceBinDeno = replaceBinDeno;
async function replaceBootstrapBash(bootstrapPath) {
    const bashPath = await which_1.default('bash');
    const bootstrapFile = await fs_extra_1.readFile(bootstrapPath, 'utf8');
    await fs_extra_1.writeFile(bootstrapPath, bootstrapFile.replace('#!/bin/sh', `#!${bashPath}`));
}
exports.replaceBootstrapBash = replaceBootstrapBash;
